@@ -32,8 +32,6 @@ from selenium.common.exceptions import (
 from selenium.webdriver.support.ui import WebDriverWait
 from selenium.webdriver.support import expected_conditions as EC
 
-from pyperclip import copy, paste
-
 logging.basicConfig()
 logger = logging.getLogger()
 logger.setLevel(logging.INFO)
@@ -481,16 +479,6 @@ def send_results_to_sheets(data):
 def by_amount(item):
     return int(item[1]["amount"].strip("$"))
 
-
-def cut_urls():
-    data = paste()
-    a = [x for x in data.split("\n") if 'href="/system/' in x]
-    b = list(
-        set([x.split('href="')[-1].split('"')[0] for x in a if "quickview" not in x])
-    )
-    copy(",\n".join(['"{}"'.format(x) for x in b]))
-    return b
-
 class CyberPowerPcBotController():
     """A program to help build a cost-effective PC."""
 
